.. meta::
    :description lang=en:
        The full emoji database, an emoji regular expression, and emoji search
        functionality in a Python module.

.. automodule:: advertools.emoji
   :members: emoji_df, extract_emoji, emoji_search
   :undoc-members:
   :show-inheritance:
